@@ -1,16 +1,16 @@
 use super::command::Command;
-use crate::cli::Cli;
 use crate::config::FnmConfig;
-use crate::shell::{infer_shell, AVAILABLE_SHELLS};
-use clap::{IntoApp, Parser};
-use clap_complete::{Generator, Shell};
+use crate::shell::{infer_shell, Shell};
+use crate::{cli::Cli, shell::Shells};
+use clap::{CommandFactory, Parser, ValueEnum};
+use clap_complete::{Generator, Shell as ClapShell};
 use thiserror::Error;
 
 #[derive(Parser, Debug)]
 pub struct Completions {
     /// The shell syntax to use. Infers when missing.
     #[clap(long)]
-    shell: Option<Shell>,
+    shell: Option<Shells>,
 }
 
 impl Command for Completions {
@@ -18,10 +18,12 @@ impl Command for Completions {
 
     fn apply(self, _config: &FnmConfig) -> Result<(), Self::Error> {
         let mut stdio = std::io::stdout();
-        let shell = self
+        let shell: Box<dyn Shell> = self
             .shell
+            .map(Into::into)
             .or_else(|| infer_shell().map(Into::into))
             .ok_or(Error::CantInferShell)?;
+        let shell: ClapShell = shell.into();
         let app = Cli::command();
         shell.generate(&app, &mut stdio);
         Ok(())
@@ -41,7 +43,7 @@ pub enum Error {
 }
 
 fn shells_as_string() -> String {
-    AVAILABLE_SHELLS
+    Shells::value_variants()
         .iter()
         .map(|x| format!("* {x}"))
         .collect::<Vec<_>>()
